@@ -44,10 +44,7 @@ class ClusterCommandBase(object):
         if not AWSParamValidator.validate_secret_key_format(config["aws_secret_key"]):
             raise UserReportableException("Malformed AWS secret key")
 
-        if not AWSParamValidator.validate_region(
-                config["aws_region"],
-                config["aws_access_key_id"],
-                config["aws_secret_key"]):
+        if not AWSParamValidator.validate_region(config["aws_region"]):
             raise ValidationException(
                 "Region {region} does not exist.".format(
                     region=config["aws_region"]))
