@@ -35,9 +35,6 @@ def generate_bright_setup(hostname, head_node_sg_id, node_sg_id, existing_subnet
     )
 
     brightsetup["modules"]["brightsetup"]["amazon"] = {
-        # WARN CM-34877: In versions before 9.0 this field was unused. For 9.0 and 9.1 we repurposed it
-        # in order to change the default region to list other regions
-        "username": config["aws_region"],
         "nodes": {
             "count": config["nodes"],
             "storage": {
@@ -48,18 +45,23 @@ def generate_bright_setup(hostname, head_node_sg_id, node_sg_id, existing_subnet
             "type": config["node_type"],
         },
         "extra_disks": [],
-        "account_id": config["aws_account_id"],
         "access_key": config["aws_access_key_id"],
         "secret_key": config["aws_secret_key"],
         "head_node_security_group_id": head_node_sg_id,
         "nodes_security_group_id": node_sg_id,
     }
 
+    brightsetup["modules"]["brightsetup"]["amazon"]["cluster_tags"] = dict(
+        (str(k), str(v)) for k, v in config["cluster_tags"])
+
     # Series of customizations depending on version
     # TODO CM-35193: We have to actually check for the revision, because these changes below work on
     #                9.0-dev and 9.1-dev, but not on older versions. To do that properly, we need also
     #                the changes from CM-35092
-    if BcmVersion(config["version"]) == "9.1":
+    if BcmVersion(config["version"]) > "9.1":
+        brightsetup["modules"]["brightsetup"]["amazon"]["api_region_name"] = config["aws_region"]
+        brightsetup["modules"]["brightsetup"]["amazon"]["image_owners"] = [config["image_owner"]]
+    elif BcmVersion(config["version"]) == "9.1":
         brightsetup["modules"]["brightsetup"]["amazon"]["image_owners"] = [config["image_owner"]]
         # CM-34877: In version 9.1 the username field was unused, so we repurposed it to get the API region
         brightsetup["modules"]["brightsetup"]["amazon"]["username"] = config["aws_region"]
