@@ -24,7 +24,7 @@ from clusterondemandconfig import ConfigNamespace, config
 
 from .cluster import Cluster
 from .configuration import awscommon_ns
-from .ec2connection import establish_connection_to_ec2
+from .ec2connection import establish_connection_to_aws
 
 log = logging.getLogger("cluster-on-demand")
 
@@ -57,18 +57,20 @@ class ClusterDelete(ClusterCommandBase):
     def run(self):
         self._validate_params()
 
-        ec2, ec2c = establish_connection_to_ec2()
+        aws_session = establish_connection_to_aws()
         prefix = None
         names = [ensure_cod_prefix(name) for name in config["name"]]
         if not names:
             prefix = config["prefix"]
 
-        clusters = Cluster.find_some(ec2, ec2c, prefix, names)
+        clusters = Cluster.find_some(aws_session, prefix, names)
         if clusters:
             names = [cluster.name for cluster in clusters]
 
-            log.info("This will destroy VPCs for %s, continue?" % (" ".join(names),))
-            if not confirm():
+            if any(c.get_efs_id() for c in clusters):
+                log.warning("Some clusters have a Cloud HA EFS storage. It will also be deleted")
+
+            if not confirm("This will destroy VPCs for %s, continue?" % (" ".join(names),)):
                 return
 
             Cluster.destroy(clusters)
