@@ -23,7 +23,7 @@ from clusterondemandconfig import ConfigNamespace, config
 
 from .cluster import Cluster
 from .configuration import awscommon_ns
-from .ec2connection import establish_connection_to_ec2
+from .ec2connection import create_ec2_resource_client, establish_connection_to_aws
 
 log = logging.getLogger("cluster-on-demand")
 
@@ -73,26 +73,60 @@ class ClusterList(ClusterCommandBase):
     def run(self):
         self._validate_params()
 
-        ec2, ec2c = establish_connection_to_ec2()
+        aws_session = establish_connection_to_aws()
+        ec2, _ = create_ec2_resource_client(aws_session)
         log.info("Listing clusters in region %s" % config["aws_region"])
 
-        clusters = list(Cluster.find(ec2, ec2c, config["filters"]))
+        clusters = list(Cluster.find(aws_session, config["filters"]))
+
         if clusters:
             rows = []
             for cluster in clusters:
-                head_node = cluster.head_node
+                head_node = cluster.primary_head_node
 
                 row = []
                 row += [cluster.name]
                 row += [cluster.vpc.id]
-                row += [cluster.head_node.id if cluster.head_node else "missing"]
-                row += [cluster.head_node.public_ip_address
-                        if cluster.head_node and cluster.head_node.public_ip_address else ""]
-                row += [cluster.head_node.state["Name"] if cluster.head_node else ""]
-                row += [cluster.head_node.instance_type if cluster.head_node else ""]
+
+                if cluster.is_ha:
+                    eip_and_associations = cluster.eip_and_associations
+
+                    primary_private_addresses = eip_and_associations.get(cluster.primary_head_node.id, [])
+                    secondary_private_addresses = eip_and_associations.get(cluster.secondary_head_node.id, [])
+                    active_private_addresses = eip_and_associations.get(cluster.active_head_node.id, [])
+
+                    primary_head_node_ip = next(
+                        (interface["Association"]["PublicIp"] for interface in primary_private_addresses
+                         if interface["Primary"] and interface.get("Association")), "")
+
+                    ha_ip = next(
+                        (interface["Association"]["PublicIp"] for interface in active_private_addresses
+                         if not interface["Primary"] and interface.get("Association")), "")
+
+                    secondary_head_node_ip = next(
+                        (interface["Association"]["PublicIp"] for interface in secondary_private_addresses
+                         if interface["Primary"] and interface.get("Association")), "")
+
+                    row += ["\n".join(
+                        [cluster.primary_head_node.id + " (A)" if cluster.primary_head_node else "missing"] +
+                        [cluster.secondary_head_node.id + " (B)" if cluster.secondary_head_node else "missing"]
+                    )]
+                    ip_types = {
+                        "A": primary_head_node_ip,
+                        "B": secondary_head_node_ip,
+                        "HA": ha_ip,
+                    }
+                    row += ["\n".join((f"{v} ({k})" for k, v in ip_types.items() if v))]
+                else:
+                    row += [cluster.primary_head_node.id if cluster.primary_head_node else "missing"]
+                    row += [cluster.primary_head_node.public_ip_address
+                            if cluster.primary_head_node and cluster.primary_head_node.public_ip_address else ""]
+
+                row += [cluster.primary_head_node.state["Name"] if cluster.primary_head_node else ""]
+                row += [cluster.primary_head_node.instance_type if cluster.primary_head_node else ""]
 
                 if head_node and head_node.image_id:
-                    img = ec2.Image(cluster.head_node.image_id)
+                    img = ec2.Image(cluster.primary_head_node.image_id)
                 else:
                     img = None
                 row += [_safe_image_name(img) if img else "none"]
