@@ -22,7 +22,7 @@ from clusterondemandconfig import ConfigNamespace, config
 
 from .cluster import Cluster
 from .configuration import awscommon_ns
-from .ec2connection import establish_connection_to_ec2
+from .ec2connection import establish_connection_to_aws
 
 log = logging.getLogger("cluster-on-demand")
 
@@ -48,13 +48,13 @@ class ClusterStop(ClusterCommandBase):
     def run(self):
         self._validate_params()
 
-        ec2, ec2c = establish_connection_to_ec2()
+        aws_session = establish_connection_to_aws()
         prefix = None
         names = config["name"]
         if not names:
             prefix = config["prefix"]
 
-        clusters = Cluster.find_some(ec2, ec2c, prefix, names)
+        clusters = Cluster.find_some(aws_session, prefix, names)
         if clusters:
             log.info("Stopping nodes for clusters %s" % " ".join(c.name for c in clusters))
             Cluster.stop(clusters, release_eip=True)
