@@ -18,20 +18,6 @@ import clusterondemand.configuration
 from clusterondemandconfig import DEFAULT_HELP_SECTION, ConfigNamespace, may_not_equal_none
 
 awscredentials_ns = ConfigNamespace("aws.credentials", help_section="AWS credentials")
-awscredentials_ns.add_parameter(
-    "aws_username",
-    help="A string identifying the AWS account or the IAM user.",
-    help_varname="USERNAME",
-    env="AWS_USERNAME",
-    default=""
-)
-awscredentials_ns.add_parameter(
-    "aws_account_id",
-    help="AWS Account ID. In a config file, this value should be enclosed in 'quotes'.",
-    help_varname="ID",
-    env="AWS_ACCOUNT_ID",
-    default=""
-)
 awscredentials_ns.add_parameter(
     "aws_access_key_id",
     help="AWS Access Key ID (generate it in AWS dashboard).",
@@ -67,18 +53,3 @@ awscommon_ns.add_parameter(
     help="This prefix is used for creating and finding new cluster in AWS.",
     help_section=DEFAULT_HELP_SECTION
 )
-
-
-TYPES_URL = "https://support.brightcomputing.com/cloudproviders/amazon/types.xml"
-
-awsinstancetype_ns = ConfigNamespace("aws.instancetype", "fetch AWS instance types")
-awsinstancetype_ns.add_parameter(
-    "types_url",
-    help=f"URL for the instance types XML file. Defaults to '{TYPES_URL}'",
-    default=TYPES_URL,
-)
-awsinstancetype_ns.add_switch_parameter(
-    "fetch_from_aws",
-    help=f"Fetch the instance types from the AWS pricing API instead of '{TYPES_URL}'. "
-    "This will make sure the values are fresh but takes longer."
-)
