@@ -77,10 +77,10 @@ def create_in_existing_vpc(cluster):
         head_node_sg_id, node_sg_id = _create_security_groups(cluster.vpc, config["ingress_icmp"])
 
     head_node_hostname = cluster.name
-    cluster.head_node = _create_head_node(
+    cluster.primary_head_node = _create_head_node(
         cluster.vpc, head_node_hostname, head_node_subnet, cluster.head_node_image, head_node_sg_id, node_sg_id)
 
-    _retry_not_found(_disable_source_dest_check, cluster.head_node)
+    _retry_not_found(_disable_source_dest_check, cluster.primary_head_node)
 
     _report_progress(22, "Done setting up VPC for %s" % cluster.name)
 
@@ -119,14 +119,14 @@ def create_vpc(cluster):
     else:
         head_node_sg_id, node_sg_id = _create_security_groups(cluster.vpc, config["ingress_icmp"])
 
-    cluster.head_node = _create_head_node(
+    cluster.primary_head_node = _create_head_node(
         cluster.vpc, head_node_hostname, public_subnet, cluster.head_node_image, head_node_sg_id, node_sg_id)
 
-    _retry_not_found(_disable_source_dest_check, cluster.head_node)
+    _retry_not_found(_disable_source_dest_check, cluster.primary_head_node)
 
     log.info("Waiting for head node to be running")
-    cluster.head_node.wait_until_running()  # must be running for being usable as gateway
-    _set_default_gateway_subnet(cluster.vpc, private_subnet, cluster.head_node)
+    cluster.primary_head_node.wait_until_running()  # must be running for being usable as gateway
+    _set_default_gateway_subnet(cluster.vpc, private_subnet, cluster.primary_head_node)
 
     _report_progress(22, "Done setting up VPC for %s" % vpc_name)
 
@@ -270,6 +270,7 @@ def _create_head_node(vpc, hostname, public_subnet, head_node_image, head_node_s
         existing_subnet_ids=config["existing_subnet_id"] if config["existing_subnet_id"] else None)
 
     cloud_init_script = """#!/bin/sh
+        mkdir -p /root/cm
         echo '%s' > /root/cm/cm-bright-setup.conf
     """ % yaml.dump(bright_setup, default_flow_style=False).replace("'", '"')
 
@@ -286,7 +287,7 @@ def _create_head_node(vpc, hostname, public_subnet, head_node_image, head_node_s
             "sed -i 's/subnets = list(self.head_node_instance.vpc.subnets.all())/" \
             "subnets = [subnet for subnet in list(self.head_node_instance.vpc.subnets.all()) " \
             "if subnet.id in self.config[\"amazon\"][\"existing_subnet_ids\"]]/g' " \
-            "/cm/local/apps/cm-setup/lib/python3.7/site-packages/cmsetup/plugins/brightsetup/stages.py\n"
+            "/cm/local/apps/cm-setup/lib/python3.9/site-packages/cmsetup/plugins/brightsetup/stages.py\n"
         # This code also has a check
         # if len(subnets) > 2:
         #    raise Exception('VPCs with more than one subnets are not supported')
@@ -360,9 +361,15 @@ def _create_head_node(vpc, hostname, public_subnet, head_node_image, head_node_s
 
     log.info("Creating the head node VM instance")
 
-    head_node_instance_name = f"{vpc.cluster_name} (Bright COD-AWS {config['version']} head node)"
-    tags = _construct_bright_tags(vpc.cluster_name, head_node_instance_name, BCM_TYPE_HEAD_NODE)
-    kwargs["TagSpecifications"] = [{"ResourceType": "instance", "Tags": tags}]
+    head_node_instance_and_ebs_name = f"{vpc.cluster_name} (Bright COD-AWS {config['version']} head node)"
+
+    headnode_tags = _construct_bright_tags(vpc.cluster_name, head_node_instance_and_ebs_name, BCM_TYPE_HEAD_NODE)
+    headnode_ebs_tags = _construct_bright_tags(vpc.cluster_name, head_node_instance_and_ebs_name)
+
+    kwargs["TagSpecifications"] = [
+        {"ResourceType": "instance", "Tags": headnode_tags},
+        {"ResourceType": "volume", "Tags": headnode_ebs_tags},
+    ]
 
     instances = public_subnet.create_instances(**kwargs)
     head_node_instance = instances[0]
